summaryrefslogtreecommitdiffstats
path: root/layout/forms/nsListControlFrame.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'layout/forms/nsListControlFrame.cpp')
-rw-r--r--layout/forms/nsListControlFrame.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/layout/forms/nsListControlFrame.cpp b/layout/forms/nsListControlFrame.cpp
index 7bd356a22..4daa470a9 100644
--- a/layout/forms/nsListControlFrame.cpp
+++ b/layout/forms/nsListControlFrame.cpp
@@ -614,17 +614,17 @@ nsListControlFrame::ReflowAsDropdown(nsPresContext* aPresContext,
nsHTMLScrollFrame::Reflow(aPresContext, aDesiredSize, state, aStatus);
}
-ScrollbarStyles
-nsListControlFrame::GetScrollbarStyles() const
+ScrollStyles
+nsListControlFrame::GetScrollStyles() const
{
// We can't express this in the style system yet; when we can, this can go away
// and GetScrollbarStyles can be devirtualized
int32_t style = IsInDropDownMode() ? NS_STYLE_OVERFLOW_AUTO
: NS_STYLE_OVERFLOW_SCROLL;
if (GetWritingMode().IsVertical()) {
- return ScrollbarStyles(style, NS_STYLE_OVERFLOW_HIDDEN);
+ return ScrollStyles(style, NS_STYLE_OVERFLOW_HIDDEN);
} else {
- return ScrollbarStyles(NS_STYLE_OVERFLOW_HIDDEN, style);
+ return ScrollStyles(NS_STYLE_OVERFLOW_HIDDEN, style);
}
}
@@ -614,17 +614,17 @@ nsListControlFrame::ReflowAsDropdown(nsPresContext* aPresContext,
{
// We can't express this in the style system yet; when we can, this can go away
- // and GetScrollbarStyles can be devirtualized
+ // and GetScrollStyles can be devirtualized
int32_t style = IsInDropDownMode() ? NS_STYLE_OVERFLOW_AUTO
: NS_STYLE_OVERFLOW_SCROLL;